# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/instancegroup/instance_group.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/instancegroup/instance_group.proto',
  package='yandex.cloud.compute.v1.instancegroup',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.compute.v1.instancegroupZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1/instancegroup;instancegroup',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:yandex/cloud/compute/v1/instancegroup/instance_group.proto\x12%yandex.cloud.compute.v1.instancegroup\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xb5\x0b\n\rInstanceGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12P\n\x06labels\x18\x06 \x03(\x0b\x32@.yandex.cloud.compute.v1.instancegroup.InstanceGroup.LabelsEntry\x12R\n\x11instance_template\x18\x07 \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.InstanceTemplate\x12H\n\x0cscale_policy\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.instancegroup.ScalePolicy\x12J\n\rdeploy_policy\x18\t \x01(\x0b\x32\x33.yandex.cloud.compute.v1.instancegroup.DeployPolicy\x12R\n\x11\x61llocation_policy\x18\n \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.AllocationPolicy\x12U\n\x13load_balancer_state\x18\x0b \x01(\x0b\x32\x38.yandex.cloud.compute.v1.instancegroup.LoadBalancerState\x12]\n\x17managed_instances_state\x18\x0c \x01(\x0b\x32<.yandex.cloud.compute.v1.instancegroup.ManagedInstancesState\x12S\n\x12load_balancer_spec\x18\x0e \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.LoadBalancerSpec\x12S\n\x12health_checks_spec\x18\x0f \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.HealthChecksSpec\x12\x1a\n\x12service_account_id\x18\x10 \x01(\t\x12K\n\x06status\x18\x11 \x01(\x0e\x32;.yandex.cloud.compute.v1.instancegroup.InstanceGroup.Status\x12\x42\n\tvariables\x18\x12 \x03(\x0b\x32/.yandex.cloud.compute.v1.instancegroup.Variable\x12\x1b\n\x13\x64\x65letion_protection\x18\x13 \x01(\x08\x12j\n\x1e\x61pplication_load_balancer_spec\x18\x14 \x01(\x0b\x32\x42.yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerSpec\x12l\n\x1f\x61pplication_load_balancer_state\x18\x15 \x01(\x0b\x32\x43.yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerState\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STARTING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08STOPPING\x10\x03\x12\x0b\n\x07STOPPED\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05\x12\n\n\x06PAUSED\x10\x06\"O\n\x1c\x41pplicationLoadBalancerState\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\x12\x16\n\x0estatus_message\x18\x02 \x01(\t\"O\n\x08Variable\x12)\n\x03key\x18\x01 \x01(\tB\x1c\x8a\xc8\x31\x05\x31-128\xf2\xc7\x31\x0f[a-zA-Z0-9._-]*\x12\x18\n\x05value\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=128\"D\n\x11LoadBalancerState\x12\x17\n\x0ftarget_group_id\x18\x01 \x01(\t\x12\x16\n\x0estatus_message\x18\x02 \x01(\t\"\xbf\x02\n\x15ManagedInstancesState\x12\x13\n\x0btarget_size\x18\x01 \x01(\x03\x12\x1c\n\x14running_actual_count\x18\x04 \x01(\x03\x12\x1e\n\x16running_outdated_count\x18\x05 \x01(\x03\x12\x18\n\x10processing_count\x18\x06 \x01(\x03\x1a\xb8\x01\n\x08Statuses\x12\x10\n\x08\x63reating\x18\x01 \x01(\x03\x12\x10\n\x08starting\x18\x02 \x01(\x03\x12\x0f\n\x07opening\x18\x03 \x01(\x03\x12\x0f\n\x07warming\x18\x04 \x01(\x03\x12\x0f\n\x07running\x18\x05 \x01(\x03\x12\x0f\n\x07\x63losing\x18\x06 \x01(\x03\x12\x10\n\x08stopping\x18\x07 \x01(\x03\x12\x10\n\x08updating\x18\x08 \x01(\x03\x12\x10\n\x08\x64\x65leting\x18\t \x01(\x03\x12\x0e\n\x06\x66\x61iled\x18\n \x01(\x03\"\x96\x0e\n\x0bScalePolicy\x12T\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32=.yandex.cloud.compute.v1.instancegroup.ScalePolicy.FixedScaleH\x00\x12R\n\nauto_scale\x18\x02 \x01(\x0b\x32<.yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScaleH\x00\x12U\n\x0ftest_auto_scale\x18\x03 \x01(\x0b\x32<.yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale\x1a\xa7\x05\n\tAutoScale\x12 \n\rmin_zone_size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1b\n\x08max_size\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x43\n\x14measurement_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31m-10m\x12=\n\x0fwarmup_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05<=10m\x12\x45\n\x16stabilization_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31m-30m\x12\x1d\n\x0cinitial_size\x18\x06 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x63\n\x14\x63pu_utilization_rule\x18\x07 \x01(\x0b\x32\x45.yandex.cloud.compute.v1.instancegroup.ScalePolicy.CpuUtilizationRule\x12\\\n\x0c\x63ustom_rules\x18\x08 \x03(\x0b\x32=.yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRuleB\x07\x82\xc8\x31\x03<=3\x12\x63\n\x0f\x61uto_scale_type\x18\t \x01(\x0e\x32J.yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.AutoScaleType\"I\n\rAutoScaleType\x12\x1f\n\x1b\x41UTO_SCALE_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05ZONAL\x10\x01\x12\x0c\n\x08REGIONAL\x10\x02\x1a<\n\x12\x43puUtilizationRule\x12&\n\x12utilization_target\x18\x01 \x01(\x01\x42\n\xfa\xc7\x31\x06\x31\x30-100\x1a\xe2\x05\n\nCustomRule\x12_\n\trule_type\x18\x01 \x01(\x0e\x32\x46.yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.RuleTypeB\x04\xe8\xc7\x31\x01\x12\x63\n\x0bmetric_type\x18\x02 \x01(\x0e\x32H.yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.MetricTypeB\x04\xe8\xc7\x31\x01\x12O\n\x0bmetric_name\x18\x03 \x01(\tB:\xe8\xc7\x31\x01\xf2\xc7\x31\x32[a-zA-Z0-9./@_][ 0-9a-zA-Z./@_,:;()\\[\\]<>-]{0,198}\x12\xb3\x01\n\x06labels\x18\x05 \x03(\x0b\x32I.yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.LabelsEntryBX\xf2\xc7\x31\x32[a-zA-Z0-9./@_][ 0-9a-zA-Z./@_,:;()\\[\\]<>-]{0,198}\xb2\xc8\x31\x1e\x12\x1c^[a-zA-Z][0-9a-zA-Z_]{0,31}$\x12\x16\n\x06target\x18\x04 \x01(\x01\x42\x06\xfa\xc7\x31\x02>0\x12\x1b\n\tfolder_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x07service\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=200\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"D\n\x08RuleType\x12\x19\n\x15RULE_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bUTILIZATION\x10\x01\x12\x0c\n\x08WORKLOAD\x10\x02\"A\n\nMetricType\x12\x1b\n\x17METRIC_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05GAUGE\x10\x01\x12\x0b\n\x07\x43OUNTER\x10\x02\x1a%\n\nFixedScale\x12\x17\n\x04size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-100B\x12\n\nscale_type\x12\x04\xc0\xc1\x31\x01\"\xee\x02\n\x0c\x44\x65ployPolicy\x12\"\n\x0fmax_unavailable\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1f\n\x0cmax_deleting\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1f\n\x0cmax_creating\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12 \n\rmax_expansion\x18\x06 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12>\n\x10startup_duration\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x30m-1h\x12N\n\x08strategy\x18\x08 \x01(\x0e\x32<.yandex.cloud.compute.v1.instancegroup.DeployPolicy.Strategy\"F\n\x08Strategy\x12\x18\n\x14STRATEGY_UNSPECIFIED\x10\x00\x12\r\n\tPROACTIVE\x10\x01\x12\x11\n\rOPPORTUNISTIC\x10\x02\"\x87\x01\n\x10\x41llocationPolicy\x12T\n\x05zones\x18\x01 \x03(\x0b\x32<.yandex.cloud.compute.v1.instancegroup.AllocationPolicy.ZoneB\x07\x82\xc8\x31\x03>=1\x1a\x1d\n\x04Zone\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xde\t\n\x10InstanceTemplate\x12\x1e\n\x0b\x64\x65scription\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8a\x01\n\x06labels\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.compute.v1.instancegroup.InstanceTemplate.LabelsEntryB5\x82\xc8\x31\x04<=64\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x19\n\x0bplatform_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12R\n\x0eresources_spec\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.compute.v1.instancegroup.ResourcesSpecB\x04\xe8\xc7\x31\x01\x12\x8e\x01\n\x08metadata\x18\x05 \x03(\x0b\x32\x45.yandex.cloud.compute.v1.instancegroup.InstanceTemplate.MetadataEntryB5\x82\xc8\x31\x05<=128\x8a\xc8\x31\x08<=262144\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12U\n\x0e\x62oot_disk_spec\x18\x06 \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.AttachedDiskSpecB\x04\xe8\xc7\x31\x01\x12^\n\x14secondary_disk_specs\x18\x07 \x03(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.AttachedDiskSpecB\x07\x82\xc8\x31\x03<=3\x12\x63\n\x17network_interface_specs\x18\x08 \x03(\x0b\x32;.yandex.cloud.compute.v1.instancegroup.NetworkInterfaceSpecB\x05\x82\xc8\x31\x01\x31\x12R\n\x11scheduling_policy\x18\t \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.SchedulingPolicy\x12\x1a\n\x12service_account_id\x18\n \x01(\t\x12P\n\x10network_settings\x18\x0b \x01(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.NetworkSettings\x12\x17\n\x04name\x18\x0c \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x1b\n\x08hostname\x18\r \x01(\tB\t\x8a\xc8\x31\x05<=128\x12P\n\x10placement_policy\x18\x0e \x01(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.PlacementPolicy\x12W\n\x10\x66ilesystem_specs\x18\x0f \x03(\x0b\x32=.yandex.cloud.compute.v1.instancegroup.AttachedFilesystemSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x02\n\x16\x41ttachedFilesystemSpec\x12P\n\x04mode\x18\x01 \x01(\x0e\x32\x42.yandex.cloud.compute.v1.instancegroup.AttachedFilesystemSpec.Mode\x12/\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x1a\xf2\xc7\x31\x16|[a-z][-_0-9a-z]{0,19}\x12\x35\n\rfilesystem_id\x18\x03 \x01(\tB\x1e\x8a\xc8\x31\x05<=128\xf2\xc7\x31\x11[-a-zA-Z0-9._{}]*\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\"\xdd\x02\n\x0fPlacementPolicy\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12\x64\n\x13host_affinity_rules\x18\x02 \x03(\x0b\x32G.yandex.cloud.compute.v1.instancegroup.PlacementPolicy.HostAffinityRule\x1a\xc7\x01\n\x10HostAffinityRule\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\\\n\x02op\x18\x02 \x01(\x0e\x32P.yandex.cloud.compute.v1.instancegroup.PlacementPolicy.HostAffinityRule.Operator\x12\x0e\n\x06values\x18\x03 \x03(\t\"8\n\x08Operator\x12\x18\n\x14OPERATOR_UNSPECIFIED\x10\x00\x12\x06\n\x02IN\x10\x01\x12\n\n\x06NOT_IN\x10\x02\"\xdf\x01\n\rResourcesSpec\x12\"\n\x06memory\x18\x01 \x01(\x03\x42\x12\xfa\xc7\x31\x0e<=824633720832\x12\x65\n\x05\x63ores\x18\x02 \x01(\x03\x42V\xfa\xc7\x31R2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,40,44,48,52,56,60,64,68,72,76,80\x12(\n\rcore_fraction\x18\x03 \x01(\x03\x42\x11\xfa\xc7\x31\r0,5,20,50,100\x12\x19\n\x04gpus\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30,1,2,4\"\xdc\x04\n\x10\x41ttachedDiskSpec\x12P\n\x04mode\x18\x01 \x01(\x0e\x32<.yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.ModeB\x04\xe8\xc7\x31\x01\x12/\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x1a\xf2\xc7\x31\x16|[a-z][-_0-9a-z]{0,19}\x12Y\n\tdisk_spec\x18\x03 \x01(\x0b\x32@.yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpecB\x04\xe8\xc7\x31\x01\x12/\n\x07\x64isk_id\x18\x04 \x01(\tB\x1e\x8a\xc8\x31\x05<=128\xf2\xc7\x31\x11[-a-zA-Z0-9._{}]*\x12\x17\n\x04name\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=128\x1a\xe2\x01\n\x08\x44iskSpec\x12\x1e\n\x0b\x64\x65scription\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x15\n\x07type_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x04size\x18\x03 \x01(\x03\x42\x1a\xfa\xc7\x31\x16\x34\x31\x39\x34\x33\x30\x34-28587302322176\x12\x1c\n\x08image_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12&\n\x1epreserve_after_instance_delete\x18\x06 \x01(\x08\x42\x0e\n\x0csource_oneof\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\"\x92\x02\n\x14NetworkInterfaceSpec\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\x12\x12\n\nsubnet_ids\x18\x02 \x03(\t\x12Z\n\x17primary_v4_address_spec\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.compute.v1.instancegroup.PrimaryAddressSpec\x12Z\n\x17primary_v6_address_spec\x18\x04 \x01(\x0b\x32\x39.yandex.cloud.compute.v1.instancegroup.PrimaryAddressSpec\x12\x1a\n\x12security_group_ids\x18\x05 \x03(\t\"\xca\x01\n\x12PrimaryAddressSpec\x12S\n\x13one_to_one_nat_spec\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.OneToOneNatSpec\x12N\n\x10\x64ns_record_specs\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.compute.v1.instancegroup.DnsRecordSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\"\xb8\x01\n\x0fOneToOneNatSpec\x12\x44\n\nip_version\x18\x01 \x01(\x0e\x32\x30.yandex.cloud.compute.v1.instancegroup.IpVersion\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12N\n\x10\x64ns_record_specs\x18\x03 \x03(\x0b\x32\x34.yandex.cloud.compute.v1.instancegroup.DnsRecordSpec\"_\n\rDnsRecordSpec\x12\x12\n\x04\x66qdn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64ns_zone_id\x18\x02 \x01(\t\x12\x18\n\x03ttl\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"\'\n\x10SchedulingPolicy\x12\x13\n\x0bpreemptible\x18\x01 \x01(\x08\"\xbc\x01\n\x0fNetworkSettings\x12I\n\x04type\x18\x01 \x01(\x0e\x32;.yandex.cloud.compute.v1.instancegroup.NetworkSettings.Type\"^\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x18\n\x14SOFTWARE_ACCELERATED\x10\x02\x12\x18\n\x14HARDWARE_ACCELERATED\x10\x03\"\xb0\x01\n\x10LoadBalancerSpec\x12Q\n\x11target_group_spec\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.TargetGroupSpec\x12I\n\x1cmax_opening_traffic_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\xc7\x31\x04>=1s\"\xb2\x02\n\x0fTargetGroupSpec\x12\x32\n\x04name\x18\x01 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9b\x01\n\x06labels\x18\x03 \x03(\x0b\x32\x42.yandex.cloud.compute.v1.instancegroup.TargetGroupSpec.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcc\x01\n\x1b\x41pplicationLoadBalancerSpec\x12\x62\n\x11target_group_spec\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpecB\x04\xe8\xc7\x31\x01\x12I\n\x1cmax_opening_traffic_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\xc7\x31\x04>=1s\"\xcd\x01\n\x1a\x41pplicationTargetGroupSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12]\n\x06labels\x18\x03 \x03(\x0b\x32M.yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xba\x01\n\x10HealthChecksSpec\x12[\n\x12health_check_specs\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.HealthCheckSpecB\x07\x82\xc8\x31\x03>=1\x12I\n\x1cmax_checking_health_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\xc7\x31\x04>=1s\"\xa4\x04\n\x0fHealthCheckSpec\x12\x38\n\x08interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x31s-300s\x12\x36\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31s-60s\x12\x35\n\x13unhealthy_threshold\x18\x03 \x01(\x03\x42\x18\xfa\xc7\x31\x14\x30,2,3,4,5,6,7,8,9,10\x12\x33\n\x11healthy_threshold\x18\x04 \x01(\x03\x42\x18\xfa\xc7\x31\x14\x30,2,3,4,5,6,7,8,9,10\x12X\n\x0btcp_options\x18\x05 \x01(\x0b\x32\x41.yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.TcpOptionsH\x00\x12Z\n\x0chttp_options\x18\x06 \x01(\x0b\x32\x42.yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.HttpOptionsH\x00\x1a\'\n\nTcpOptions\x12\x19\n\x04port\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65535\x1a\x36\n\x0bHttpOptions\x12\x19\n\x04port\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65535\x12\x0c\n\x04path\x18\x02 \x01(\tB\x1c\n\x14health_check_options\x12\x04\xc0\xc1\x31\x01\"\xc1\x05\n\x0fManagedInstance\x12\n\n\x02id\x18\x01 \x01(\t\x12M\n\x06status\x18\x02 \x01(\x0e\x32=.yandex.cloud.compute.v1.instancegroup.ManagedInstance.Status\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x0c\n\x04\x66qdn\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x16\n\x0estatus_message\x18\x06 \x01(\t\x12\x0f\n\x07zone_id\x18\x07 \x01(\t\x12S\n\x12network_interfaces\x18\x08 \x03(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.NetworkInterface\x12\x35\n\x11status_changed_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xec\x02\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11\x43REATING_INSTANCE\x10\x0b\x12\x15\n\x11UPDATING_INSTANCE\x10\x0c\x12\x15\n\x11\x44\x45LETING_INSTANCE\x10\r\x12\x15\n\x11STARTING_INSTANCE\x10\x0e\x12\x15\n\x11STOPPING_INSTANCE\x10\x0f\x12\x1d\n\x19\x41WAITING_STARTUP_DURATION\x10\x10\x12\x13\n\x0f\x43HECKING_HEALTH\x10\x11\x12\x13\n\x0fOPENING_TRAFFIC\x10\x12\x12\x1c\n\x18\x41WAITING_WARMUP_DURATION\x10\x13\x12\x13\n\x0f\x43LOSING_TRAFFIC\x10\x14\x12\x12\n\x0eRUNNING_ACTUAL\x10\x15\x12\x14\n\x10RUNNING_OUTDATED\x10\x16\x12\x0b\n\x07STOPPED\x10\x17\x12\x0b\n\x07\x44\x45LETED\x10\x18\x12\x17\n\x13PREPARING_RESOURCES\x10\x19\"\xef\x01\n\x10NetworkInterface\x12\r\n\x05index\x18\x01 \x01(\t\x12\x13\n\x0bmac_address\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\x12Q\n\x12primary_v4_address\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.compute.v1.instancegroup.PrimaryAddress\x12Q\n\x12primary_v6_address\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.compute.v1.instancegroup.PrimaryAddress\"\xb4\x01\n\x0ePrimaryAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12J\n\x0eone_to_one_nat\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.instancegroup.OneToOneNat\x12\x45\n\x0b\x64ns_records\x18\x03 \x03(\x0b\x32\x30.yandex.cloud.compute.v1.instancegroup.DnsRecord\"\xab\x01\n\x0bOneToOneNat\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x44\n\nip_version\x18\x02 \x01(\x0e\x32\x30.yandex.cloud.compute.v1.instancegroup.IpVersion\x12\x45\n\x0b\x64ns_records\x18\x03 \x03(\x0b\x32\x30.yandex.cloud.compute.v1.instancegroup.DnsRecord\"[\n\tDnsRecord\x12\x12\n\x04\x66qdn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64ns_zone_id\x18\x02 \x01(\t\x12\x18\n\x03ttl\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"K\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x02 \x01(\t*;\n\tIpVersion\x12\x1a\n\x16IP_VERSION_UNSPECIFIED\x10\x00\x12\x08\n\x04IPV4\x10\x01\x12\x08\n\x04IPV6\x10\x02\x42\x84\x01\n)yandex.cloud.api.compute.v1.instancegroupZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1/instancegroup;instancegroupb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])

_IPVERSION = _descriptor.EnumDescriptor(
  name='IpVersion',
  full_name='yandex.cloud.compute.v1.instancegroup.IpVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IP_VERSION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IPV4', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IPV6', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11365,
  serialized_end=11424,
)
_sym_db.RegisterEnumDescriptor(_IPVERSION)

IpVersion = enum_type_wrapper.EnumTypeWrapper(_IPVERSION)
IP_VERSION_UNSPECIFIED = 0
IPV4 = 1
IPV6 = 2


_INSTANCEGROUP_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1548,
  serialized_end=1659,
)
_sym_db.RegisterEnumDescriptor(_INSTANCEGROUP_STATUS)

_SCALEPOLICY_AUTOSCALE_AUTOSCALETYPE = _descriptor.EnumDescriptor(
  name='AutoScaleType',
  full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.AutoScaleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO_SCALE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZONAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REGIONAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3095,
  serialized_end=3168,
)
_sym_db.RegisterEnumDescriptor(_SCALEPOLICY_AUTOSCALE_AUTOSCALETYPE)

_SCALEPOLICY_CUSTOMRULE_RULETYPE = _descriptor.EnumDescriptor(
  name='RuleType',
  full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.RuleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RULE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UTILIZATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WORKLOAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3836,
  serialized_end=3904,
)
_sym_db.RegisterEnumDescriptor(_SCALEPOLICY_CUSTOMRULE_RULETYPE)

_SCALEPOLICY_CUSTOMRULE_METRICTYPE = _descriptor.EnumDescriptor(
  name='MetricType',
  full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.MetricType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='METRIC_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAUGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COUNTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3906,
  serialized_end=3971,
)
_sym_db.RegisterEnumDescriptor(_SCALEPOLICY_CUSTOMRULE_METRICTYPE)

_DEPLOYPOLICY_STRATEGY = _descriptor.EnumDescriptor(
  name='Strategy',
  full_name='yandex.cloud.compute.v1.instancegroup.DeployPolicy.Strategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STRATEGY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPPORTUNISTIC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4329,
  serialized_end=4399,
)
_sym_db.RegisterEnumDescriptor(_DEPLOYPOLICY_STRATEGY)

_ATTACHEDFILESYSTEMSPEC_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.compute.v1.instancegroup.AttachedFilesystemSpec.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_WRITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6001,
  serialized_end=6060,
)
_sym_db.RegisterEnumDescriptor(_ATTACHEDFILESYSTEMSPEC_MODE)

_PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR = _descriptor.EnumDescriptor(
  name='Operator',
  full_name='yandex.cloud.compute.v1.instancegroup.PlacementPolicy.HostAffinityRule.Operator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPERATOR_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_IN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6356,
  serialized_end=6412,
)
_sym_db.RegisterEnumDescriptor(_PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR)

_ATTACHEDDISKSPEC_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_WRITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6001,
  serialized_end=6060,
)
_sym_db.RegisterEnumDescriptor(_ATTACHEDDISKSPEC_MODE)

_NETWORKSETTINGS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yandex.cloud.compute.v1.instancegroup.NetworkSettings.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STANDARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOFTWARE_ACCELERATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HARDWARE_ACCELERATED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8149,
  serialized_end=8243,
)
_sym_db.RegisterEnumDescriptor(_NETWORKSETTINGS_TYPE)

_MANAGEDINSTANCE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING_INSTANCE', index=1, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATING_INSTANCE', index=2, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING_INSTANCE', index=3, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTING_INSTANCE', index=4, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPING_INSTANCE', index=5, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AWAITING_STARTUP_DURATION', index=6, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHECKING_HEALTH', index=7, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPENING_TRAFFIC', index=8, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AWAITING_WARMUP_DURATION', index=9, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOSING_TRAFFIC', index=10, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING_ACTUAL', index=11, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING_OUTDATED', index=12, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=13, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=14, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREPARING_RESOURCES', index=15, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10230,
  serialized_end=10594,
)
_sym_db.RegisterEnumDescriptor(_MANAGEDINSTANCE_STATUS)


_INSTANCEGROUP_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1546,
)

_INSTANCEGROUP = _descriptor.Descriptor(
  name='InstanceGroup',
  full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_template', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.instance_template', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.scale_policy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_policy', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.deploy_policy', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocation_policy', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.allocation_policy', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancer_state', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.load_balancer_state', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='managed_instances_state', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.managed_instances_state', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancer_spec', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.load_balancer_spec', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_checks_spec', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.health_checks_spec', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.service_account_id', index=14,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.status', index=15,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.variables', index=16,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.deletion_protection', index=17,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_load_balancer_spec', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.application_load_balancer_spec', index=18,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_load_balancer_state', full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroup.application_load_balancer_state', index=19,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INSTANCEGROUP_LABELSENTRY, ],
  enum_types=[
    _INSTANCEGROUP_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=1659,
)


_APPLICATIONLOADBALANCERSTATE = _descriptor.Descriptor(
  name='ApplicationLoadBalancerState',
  full_name='yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerState.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_message', full_name='yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerState.status_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1661,
  serialized_end=1740,
)


_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='yandex.cloud.compute.v1.instancegroup.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.instancegroup.Variable.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\0051-128\362\3071\017[a-zA-Z0-9._-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.instancegroup.Variable.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=128', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1742,
  serialized_end=1821,
)


_LOADBALANCERSTATE = _descriptor.Descriptor(
  name='LoadBalancerState',
  full_name='yandex.cloud.compute.v1.instancegroup.LoadBalancerState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.compute.v1.instancegroup.LoadBalancerState.target_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_message', full_name='yandex.cloud.compute.v1.instancegroup.LoadBalancerState.status_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1823,
  serialized_end=1891,
)


_MANAGEDINSTANCESSTATE_STATUSES = _descriptor.Descriptor(
  name='Statuses',
  full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='creating', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses.creating', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='starting', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses.starting', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opening', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses.opening', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warming', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses.warming', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses.running', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='closing', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses.closing', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stopping', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses.stopping', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updating', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses.updating', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleting', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses.deleting', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failed', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses.failed', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2029,
  serialized_end=2213,
)

_MANAGEDINSTANCESSTATE = _descriptor.Descriptor(
  name='ManagedInstancesState',
  full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_size', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.target_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_actual_count', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.running_actual_count', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_outdated_count', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.running_outdated_count', index=2,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_count', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.processing_count', index=3,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MANAGEDINSTANCESSTATE_STATUSES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1894,
  serialized_end=2213,
)


_SCALEPOLICY_AUTOSCALE = _descriptor.Descriptor(
  name='AutoScale',
  full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_zone_size', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.min_zone_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_size', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.max_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_duration', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.measurement_duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0061m-10m', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warmup_duration', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.warmup_duration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\005<=10m', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stabilization_duration', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.stabilization_duration', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0061m-30m', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_size', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.initial_size', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_utilization_rule', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.cpu_utilization_rule', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_rules', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.custom_rules', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003<=3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_scale_type', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale.auto_scale_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCALEPOLICY_AUTOSCALE_AUTOSCALETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2489,
  serialized_end=3168,
)

_SCALEPOLICY_CPUUTILIZATIONRULE = _descriptor.Descriptor(
  name='CpuUtilizationRule',
  full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CpuUtilizationRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='utilization_target', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CpuUtilizationRule.utilization_target', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\00610-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3170,
  serialized_end=3230,
)

_SCALEPOLICY_CUSTOMRULE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1546,
)

_SCALEPOLICY_CUSTOMRULE = _descriptor.Descriptor(
  name='CustomRule',
  full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule_type', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.rule_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_type', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.metric_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.metric_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\30712[a-zA-Z0-9./@_][ 0-9a-zA-Z./@_,:;()\\[\\]<>-]{0,198}', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.labels', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\30712[a-zA-Z0-9./@_][ 0-9a-zA-Z./@_,:;()\\[\\]<>-]{0,198}\262\3101\036\022\034^[a-zA-Z][0-9a-zA-Z_]{0,31}$', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.target', index=4,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.folder_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.service', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=200', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCALEPOLICY_CUSTOMRULE_LABELSENTRY, ],
  enum_types=[
    _SCALEPOLICY_CUSTOMRULE_RULETYPE,
    _SCALEPOLICY_CUSTOMRULE_METRICTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3233,
  serialized_end=3971,
)

_SCALEPOLICY_FIXEDSCALE = _descriptor.Descriptor(
  name='FixedScale',
  full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.FixedScale',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.FixedScale.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0051-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3973,
  serialized_end=4010,
)

_SCALEPOLICY = _descriptor.Descriptor(
  name='ScalePolicy',
  full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fixed_scale', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.fixed_scale', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_scale', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.auto_scale', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_auto_scale', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.test_auto_scale', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCALEPOLICY_AUTOSCALE, _SCALEPOLICY_CPUUTILIZATIONRULE, _SCALEPOLICY_CUSTOMRULE, _SCALEPOLICY_FIXEDSCALE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='scale_type', full_name='yandex.cloud.compute.v1.instancegroup.ScalePolicy.scale_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2216,
  serialized_end=4030,
)


_DEPLOYPOLICY = _descriptor.Descriptor(
  name='DeployPolicy',
  full_name='yandex.cloud.compute.v1.instancegroup.DeployPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_unavailable', full_name='yandex.cloud.compute.v1.instancegroup.DeployPolicy.max_unavailable', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_deleting', full_name='yandex.cloud.compute.v1.instancegroup.DeployPolicy.max_deleting', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_creating', full_name='yandex.cloud.compute.v1.instancegroup.DeployPolicy.max_creating', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_expansion', full_name='yandex.cloud.compute.v1.instancegroup.DeployPolicy.max_expansion', index=3,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startup_duration', full_name='yandex.cloud.compute.v1.instancegroup.DeployPolicy.startup_duration', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050m-1h', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='yandex.cloud.compute.v1.instancegroup.DeployPolicy.strategy', index=5,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEPLOYPOLICY_STRATEGY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4033,
  serialized_end=4399,
)


_ALLOCATIONPOLICY_ZONE = _descriptor.Descriptor(
  name='Zone',
  full_name='yandex.cloud.compute.v1.instancegroup.AllocationPolicy.Zone',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.compute.v1.instancegroup.AllocationPolicy.Zone.zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4508,
  serialized_end=4537,
)

_ALLOCATIONPOLICY = _descriptor.Descriptor(
  name='AllocationPolicy',
  full_name='yandex.cloud.compute.v1.instancegroup.AllocationPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='zones', full_name='yandex.cloud.compute.v1.instancegroup.AllocationPolicy.zones', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ALLOCATIONPOLICY_ZONE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4402,
  serialized_end=4537,
)


_INSTANCETEMPLATE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1546,
)

_INSTANCETEMPLATE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5739,
  serialized_end=5786,
)

_INSTANCETEMPLATE = _descriptor.Descriptor(
  name='InstanceTemplate',
  full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\005<=128\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform_id', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.platform_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_spec', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.resources_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.metadata', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\005<=128\212\3101\010<=262144\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boot_disk_spec', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.boot_disk_spec', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_disk_specs', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.secondary_disk_specs', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003<=3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_interface_specs', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.network_interface_specs', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0011', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheduling_policy', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.scheduling_policy', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.service_account_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_settings', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.network_settings', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.name', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=128', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.hostname', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=128', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_policy', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.placement_policy', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesystem_specs', full_name='yandex.cloud.compute.v1.instancegroup.InstanceTemplate.filesystem_specs', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INSTANCETEMPLATE_LABELSENTRY, _INSTANCETEMPLATE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4540,
  serialized_end=5786,
)


_ATTACHEDFILESYSTEMSPEC = _descriptor.Descriptor(
  name='AttachedFilesystemSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.AttachedFilesystemSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.compute.v1.instancegroup.AttachedFilesystemSpec.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='yandex.cloud.compute.v1.instancegroup.AttachedFilesystemSpec.device_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\026|[a-z][-_0-9a-z]{0,19}', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesystem_id', full_name='yandex.cloud.compute.v1.instancegroup.AttachedFilesystemSpec.filesystem_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=128\362\3071\021[-a-zA-Z0-9._{}]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ATTACHEDFILESYSTEMSPEC_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5789,
  serialized_end=6060,
)


_PLACEMENTPOLICY_HOSTAFFINITYRULE = _descriptor.Descriptor(
  name='HostAffinityRule',
  full_name='yandex.cloud.compute.v1.instancegroup.PlacementPolicy.HostAffinityRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.instancegroup.PlacementPolicy.HostAffinityRule.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='op', full_name='yandex.cloud.compute.v1.instancegroup.PlacementPolicy.HostAffinityRule.op', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='yandex.cloud.compute.v1.instancegroup.PlacementPolicy.HostAffinityRule.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6213,
  serialized_end=6412,
)

_PLACEMENTPOLICY = _descriptor.Descriptor(
  name='PlacementPolicy',
  full_name='yandex.cloud.compute.v1.instancegroup.PlacementPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.instancegroup.PlacementPolicy.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_affinity_rules', full_name='yandex.cloud.compute.v1.instancegroup.PlacementPolicy.host_affinity_rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PLACEMENTPOLICY_HOSTAFFINITYRULE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6063,
  serialized_end=6412,
)


_RESOURCESSPEC = _descriptor.Descriptor(
  name='ResourcesSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.ResourcesSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory', full_name='yandex.cloud.compute.v1.instancegroup.ResourcesSpec.memory', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\016<=824633720832', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cores', full_name='yandex.cloud.compute.v1.instancegroup.ResourcesSpec.cores', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071R2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,40,44,48,52,56,60,64,68,72,76,80', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='core_fraction', full_name='yandex.cloud.compute.v1.instancegroup.ResourcesSpec.core_fraction', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\r0,5,20,50,100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpus', full_name='yandex.cloud.compute.v1.instancegroup.ResourcesSpec.gpus', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070,1,2,4', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6415,
  serialized_end=6638,
)


_ATTACHEDDISKSPEC_DISKSPEC = _descriptor.Descriptor(
  name='DiskSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpec.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_id', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpec.type_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpec.size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0264194304-28587302322176', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpec.image_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_id', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpec.snapshot_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preserve_after_instance_delete', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpec.preserve_after_instance_delete', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source_oneof', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpec.source_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6958,
  serialized_end=7184,
)

_ATTACHEDDISKSPEC = _descriptor.Descriptor(
  name='AttachedDiskSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.device_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\026|[a-z][-_0-9a-z]{0,19}', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_spec', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.disk_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.disk_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=128\362\3071\021[-a-zA-Z0-9._{}]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.name', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=128', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ATTACHEDDISKSPEC_DISKSPEC, ],
  enum_types=[
    _ATTACHEDDISKSPEC_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6641,
  serialized_end=7245,
)


_NETWORKINTERFACESPEC = _descriptor.Descriptor(
  name='NetworkInterfaceSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterfaceSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterfaceSpec.network_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterfaceSpec.subnet_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_v4_address_spec', full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterfaceSpec.primary_v4_address_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_v6_address_spec', full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterfaceSpec.primary_v6_address_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterfaceSpec.security_group_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7248,
  serialized_end=7522,
)


_PRIMARYADDRESSSPEC = _descriptor.Descriptor(
  name='PrimaryAddressSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.PrimaryAddressSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='one_to_one_nat_spec', full_name='yandex.cloud.compute.v1.instancegroup.PrimaryAddressSpec.one_to_one_nat_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_record_specs', full_name='yandex.cloud.compute.v1.instancegroup.PrimaryAddressSpec.dns_record_specs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.compute.v1.instancegroup.PrimaryAddressSpec.address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7525,
  serialized_end=7727,
)


_ONETOONENATSPEC = _descriptor.Descriptor(
  name='OneToOneNatSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.OneToOneNatSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_version', full_name='yandex.cloud.compute.v1.instancegroup.OneToOneNatSpec.ip_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.compute.v1.instancegroup.OneToOneNatSpec.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_record_specs', full_name='yandex.cloud.compute.v1.instancegroup.OneToOneNatSpec.dns_record_specs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7730,
  serialized_end=7914,
)


_DNSRECORDSPEC = _descriptor.Descriptor(
  name='DnsRecordSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.DnsRecordSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fqdn', full_name='yandex.cloud.compute.v1.instancegroup.DnsRecordSpec.fqdn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.compute.v1.instancegroup.DnsRecordSpec.dns_zone_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='yandex.cloud.compute.v1.instancegroup.DnsRecordSpec.ttl', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-86400', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ptr', full_name='yandex.cloud.compute.v1.instancegroup.DnsRecordSpec.ptr', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7916,
  serialized_end=8011,
)


_SCHEDULINGPOLICY = _descriptor.Descriptor(
  name='SchedulingPolicy',
  full_name='yandex.cloud.compute.v1.instancegroup.SchedulingPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preemptible', full_name='yandex.cloud.compute.v1.instancegroup.SchedulingPolicy.preemptible', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8013,
  serialized_end=8052,
)


_NETWORKSETTINGS = _descriptor.Descriptor(
  name='NetworkSettings',
  full_name='yandex.cloud.compute.v1.instancegroup.NetworkSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.compute.v1.instancegroup.NetworkSettings.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NETWORKSETTINGS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8055,
  serialized_end=8243,
)


_LOADBALANCERSPEC = _descriptor.Descriptor(
  name='LoadBalancerSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.LoadBalancerSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_spec', full_name='yandex.cloud.compute.v1.instancegroup.LoadBalancerSpec.target_group_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_opening_traffic_duration', full_name='yandex.cloud.compute.v1.instancegroup.LoadBalancerSpec.max_opening_traffic_duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\004>=1s', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8246,
  serialized_end=8422,
)


_TARGETGROUPSPEC_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.instancegroup.TargetGroupSpec.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.instancegroup.TargetGroupSpec.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.instancegroup.TargetGroupSpec.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1546,
)

_TARGETGROUPSPEC = _descriptor.Descriptor(
  name='TargetGroupSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.TargetGroupSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.instancegroup.TargetGroupSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.instancegroup.TargetGroupSpec.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.instancegroup.TargetGroupSpec.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TARGETGROUPSPEC_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8425,
  serialized_end=8731,
)


_APPLICATIONLOADBALANCERSPEC = _descriptor.Descriptor(
  name='ApplicationLoadBalancerSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_group_spec', full_name='yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerSpec.target_group_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_opening_traffic_duration', full_name='yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerSpec.max_opening_traffic_duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\004>=1s', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8734,
  serialized_end=8938,
)


_APPLICATIONTARGETGROUPSPEC_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1546,
)

_APPLICATIONTARGETGROUPSPEC = _descriptor.Descriptor(
  name='ApplicationTargetGroupSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_APPLICATIONTARGETGROUPSPEC_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8941,
  serialized_end=9146,
)


_HEALTHCHECKSSPEC = _descriptor.Descriptor(
  name='HealthChecksSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.HealthChecksSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='health_check_specs', full_name='yandex.cloud.compute.v1.instancegroup.HealthChecksSpec.health_check_specs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_checking_health_duration', full_name='yandex.cloud.compute.v1.instancegroup.HealthChecksSpec.max_checking_health_duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\004>=1s', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9149,
  serialized_end=9335,
)


_HEALTHCHECKSPEC_TCPOPTIONS = _descriptor.Descriptor(
  name='TcpOptions',
  full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.TcpOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.TcpOptions.port', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0071-65535', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9761,
  serialized_end=9800,
)

_HEALTHCHECKSPEC_HTTPOPTIONS = _descriptor.Descriptor(
  name='HttpOptions',
  full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.HttpOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.HttpOptions.port', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0071-65535', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.HttpOptions.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9802,
  serialized_end=9856,
)

_HEALTHCHECKSPEC = _descriptor.Descriptor(
  name='HealthCheckSpec',
  full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval', full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0071s-300s', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0061s-60s', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unhealthy_threshold', full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.unhealthy_threshold', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0240,2,3,4,5,6,7,8,9,10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthy_threshold', full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.healthy_threshold', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0240,2,3,4,5,6,7,8,9,10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_options', full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.tcp_options', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_options', full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.http_options', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HEALTHCHECKSPEC_TCPOPTIONS, _HEALTHCHECKSPEC_HTTPOPTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='health_check_options', full_name='yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.health_check_options',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=9338,
  serialized_end=9886,
)


_MANAGEDINSTANCE = _descriptor.Descriptor(
  name='ManagedInstance',
  full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance.instance_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fqdn', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance.fqdn', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_message', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance.status_message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance.zone_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_interfaces', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance.network_interfaces', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_changed_at', full_name='yandex.cloud.compute.v1.instancegroup.ManagedInstance.status_changed_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MANAGEDINSTANCE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9889,
  serialized_end=10594,
)


_NETWORKINTERFACE = _descriptor.Descriptor(
  name='NetworkInterface',
  full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterface.index', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac_address', full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterface.mac_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterface.subnet_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_v4_address', full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterface.primary_v4_address', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_v6_address', full_name='yandex.cloud.compute.v1.instancegroup.NetworkInterface.primary_v6_address', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10597,
  serialized_end=10836,
)


_PRIMARYADDRESS = _descriptor.Descriptor(
  name='PrimaryAddress',
  full_name='yandex.cloud.compute.v1.instancegroup.PrimaryAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.compute.v1.instancegroup.PrimaryAddress.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_to_one_nat', full_name='yandex.cloud.compute.v1.instancegroup.PrimaryAddress.one_to_one_nat', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_records', full_name='yandex.cloud.compute.v1.instancegroup.PrimaryAddress.dns_records', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10839,
  serialized_end=11019,
)


_ONETOONENAT = _descriptor.Descriptor(
  name='OneToOneNat',
  full_name='yandex.cloud.compute.v1.instancegroup.OneToOneNat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.compute.v1.instancegroup.OneToOneNat.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_version', full_name='yandex.cloud.compute.v1.instancegroup.OneToOneNat.ip_version', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_records', full_name='yandex.cloud.compute.v1.instancegroup.OneToOneNat.dns_records', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11022,
  serialized_end=11193,
)


_DNSRECORD = _descriptor.Descriptor(
  name='DnsRecord',
  full_name='yandex.cloud.compute.v1.instancegroup.DnsRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fqdn', full_name='yandex.cloud.compute.v1.instancegroup.DnsRecord.fqdn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.compute.v1.instancegroup.DnsRecord.dns_zone_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='yandex.cloud.compute.v1.instancegroup.DnsRecord.ttl', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-86400', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ptr', full_name='yandex.cloud.compute.v1.instancegroup.DnsRecord.ptr', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11195,
  serialized_end=11286,
)


_LOGRECORD = _descriptor.Descriptor(
  name='LogRecord',
  full_name='yandex.cloud.compute.v1.instancegroup.LogRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='yandex.cloud.compute.v1.instancegroup.LogRecord.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='yandex.cloud.compute.v1.instancegroup.LogRecord.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11288,
  serialized_end=11363,
)

_INSTANCEGROUP_LABELSENTRY.containing_type = _INSTANCEGROUP
_INSTANCEGROUP.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INSTANCEGROUP.fields_by_name['labels'].message_type = _INSTANCEGROUP_LABELSENTRY
_INSTANCEGROUP.fields_by_name['instance_template'].message_type = _INSTANCETEMPLATE
_INSTANCEGROUP.fields_by_name['scale_policy'].message_type = _SCALEPOLICY
_INSTANCEGROUP.fields_by_name['deploy_policy'].message_type = _DEPLOYPOLICY
_INSTANCEGROUP.fields_by_name['allocation_policy'].message_type = _ALLOCATIONPOLICY
_INSTANCEGROUP.fields_by_name['load_balancer_state'].message_type = _LOADBALANCERSTATE
_INSTANCEGROUP.fields_by_name['managed_instances_state'].message_type = _MANAGEDINSTANCESSTATE
_INSTANCEGROUP.fields_by_name['load_balancer_spec'].message_type = _LOADBALANCERSPEC
_INSTANCEGROUP.fields_by_name['health_checks_spec'].message_type = _HEALTHCHECKSSPEC
_INSTANCEGROUP.fields_by_name['status'].enum_type = _INSTANCEGROUP_STATUS
_INSTANCEGROUP.fields_by_name['variables'].message_type = _VARIABLE
_INSTANCEGROUP.fields_by_name['application_load_balancer_spec'].message_type = _APPLICATIONLOADBALANCERSPEC
_INSTANCEGROUP.fields_by_name['application_load_balancer_state'].message_type = _APPLICATIONLOADBALANCERSTATE
_INSTANCEGROUP_STATUS.containing_type = _INSTANCEGROUP
_MANAGEDINSTANCESSTATE_STATUSES.containing_type = _MANAGEDINSTANCESSTATE
_SCALEPOLICY_AUTOSCALE.fields_by_name['measurement_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SCALEPOLICY_AUTOSCALE.fields_by_name['warmup_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SCALEPOLICY_AUTOSCALE.fields_by_name['stabilization_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SCALEPOLICY_AUTOSCALE.fields_by_name['cpu_utilization_rule'].message_type = _SCALEPOLICY_CPUUTILIZATIONRULE
_SCALEPOLICY_AUTOSCALE.fields_by_name['custom_rules'].message_type = _SCALEPOLICY_CUSTOMRULE
_SCALEPOLICY_AUTOSCALE.fields_by_name['auto_scale_type'].enum_type = _SCALEPOLICY_AUTOSCALE_AUTOSCALETYPE
_SCALEPOLICY_AUTOSCALE.containing_type = _SCALEPOLICY
_SCALEPOLICY_AUTOSCALE_AUTOSCALETYPE.containing_type = _SCALEPOLICY_AUTOSCALE
_SCALEPOLICY_CPUUTILIZATIONRULE.containing_type = _SCALEPOLICY
_SCALEPOLICY_CUSTOMRULE_LABELSENTRY.containing_type = _SCALEPOLICY_CUSTOMRULE
_SCALEPOLICY_CUSTOMRULE.fields_by_name['rule_type'].enum_type = _SCALEPOLICY_CUSTOMRULE_RULETYPE
_SCALEPOLICY_CUSTOMRULE.fields_by_name['metric_type'].enum_type = _SCALEPOLICY_CUSTOMRULE_METRICTYPE
_SCALEPOLICY_CUSTOMRULE.fields_by_name['labels'].message_type = _SCALEPOLICY_CUSTOMRULE_LABELSENTRY
_SCALEPOLICY_CUSTOMRULE.containing_type = _SCALEPOLICY
_SCALEPOLICY_CUSTOMRULE_RULETYPE.containing_type = _SCALEPOLICY_CUSTOMRULE
_SCALEPOLICY_CUSTOMRULE_METRICTYPE.containing_type = _SCALEPOLICY_CUSTOMRULE
_SCALEPOLICY_FIXEDSCALE.containing_type = _SCALEPOLICY
_SCALEPOLICY.fields_by_name['fixed_scale'].message_type = _SCALEPOLICY_FIXEDSCALE
_SCALEPOLICY.fields_by_name['auto_scale'].message_type = _SCALEPOLICY_AUTOSCALE
_SCALEPOLICY.fields_by_name['test_auto_scale'].message_type = _SCALEPOLICY_AUTOSCALE
_SCALEPOLICY.oneofs_by_name['scale_type'].fields.append(
  _SCALEPOLICY.fields_by_name['fixed_scale'])
_SCALEPOLICY.fields_by_name['fixed_scale'].containing_oneof = _SCALEPOLICY.oneofs_by_name['scale_type']
_SCALEPOLICY.oneofs_by_name['scale_type'].fields.append(
  _SCALEPOLICY.fields_by_name['auto_scale'])
_SCALEPOLICY.fields_by_name['auto_scale'].containing_oneof = _SCALEPOLICY.oneofs_by_name['scale_type']
_DEPLOYPOLICY.fields_by_name['startup_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DEPLOYPOLICY.fields_by_name['strategy'].enum_type = _DEPLOYPOLICY_STRATEGY
_DEPLOYPOLICY_STRATEGY.containing_type = _DEPLOYPOLICY
_ALLOCATIONPOLICY_ZONE.containing_type = _ALLOCATIONPOLICY
_ALLOCATIONPOLICY.fields_by_name['zones'].message_type = _ALLOCATIONPOLICY_ZONE
_INSTANCETEMPLATE_LABELSENTRY.containing_type = _INSTANCETEMPLATE
_INSTANCETEMPLATE_METADATAENTRY.containing_type = _INSTANCETEMPLATE
_INSTANCETEMPLATE.fields_by_name['labels'].message_type = _INSTANCETEMPLATE_LABELSENTRY
_INSTANCETEMPLATE.fields_by_name['resources_spec'].message_type = _RESOURCESSPEC
_INSTANCETEMPLATE.fields_by_name['metadata'].message_type = _INSTANCETEMPLATE_METADATAENTRY
_INSTANCETEMPLATE.fields_by_name['boot_disk_spec'].message_type = _ATTACHEDDISKSPEC
_INSTANCETEMPLATE.fields_by_name['secondary_disk_specs'].message_type = _ATTACHEDDISKSPEC
_INSTANCETEMPLATE.fields_by_name['network_interface_specs'].message_type = _NETWORKINTERFACESPEC
_INSTANCETEMPLATE.fields_by_name['scheduling_policy'].message_type = _SCHEDULINGPOLICY
_INSTANCETEMPLATE.fields_by_name['network_settings'].message_type = _NETWORKSETTINGS
_INSTANCETEMPLATE.fields_by_name['placement_policy'].message_type = _PLACEMENTPOLICY
_INSTANCETEMPLATE.fields_by_name['filesystem_specs'].message_type = _ATTACHEDFILESYSTEMSPEC
_ATTACHEDFILESYSTEMSPEC.fields_by_name['mode'].enum_type = _ATTACHEDFILESYSTEMSPEC_MODE
_ATTACHEDFILESYSTEMSPEC_MODE.containing_type = _ATTACHEDFILESYSTEMSPEC
_PLACEMENTPOLICY_HOSTAFFINITYRULE.fields_by_name['op'].enum_type = _PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR
_PLACEMENTPOLICY_HOSTAFFINITYRULE.containing_type = _PLACEMENTPOLICY
_PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR.containing_type = _PLACEMENTPOLICY_HOSTAFFINITYRULE
_PLACEMENTPOLICY.fields_by_name['host_affinity_rules'].message_type = _PLACEMENTPOLICY_HOSTAFFINITYRULE
_ATTACHEDDISKSPEC_DISKSPEC.containing_type = _ATTACHEDDISKSPEC
_ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source_oneof'].fields.append(
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id'])
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id'].containing_oneof = _ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source_oneof']
_ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source_oneof'].fields.append(
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id'])
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id'].containing_oneof = _ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source_oneof']
_ATTACHEDDISKSPEC.fields_by_name['mode'].enum_type = _ATTACHEDDISKSPEC_MODE
_ATTACHEDDISKSPEC.fields_by_name['disk_spec'].message_type = _ATTACHEDDISKSPEC_DISKSPEC
_ATTACHEDDISKSPEC_MODE.containing_type = _ATTACHEDDISKSPEC
_NETWORKINTERFACESPEC.fields_by_name['primary_v4_address_spec'].message_type = _PRIMARYADDRESSSPEC
_NETWORKINTERFACESPEC.fields_by_name['primary_v6_address_spec'].message_type = _PRIMARYADDRESSSPEC
_PRIMARYADDRESSSPEC.fields_by_name['one_to_one_nat_spec'].message_type = _ONETOONENATSPEC
_PRIMARYADDRESSSPEC.fields_by_name['dns_record_specs'].message_type = _DNSRECORDSPEC
_ONETOONENATSPEC.fields_by_name['ip_version'].enum_type = _IPVERSION
_ONETOONENATSPEC.fields_by_name['dns_record_specs'].message_type = _DNSRECORDSPEC
_NETWORKSETTINGS.fields_by_name['type'].enum_type = _NETWORKSETTINGS_TYPE
_NETWORKSETTINGS_TYPE.containing_type = _NETWORKSETTINGS
_LOADBALANCERSPEC.fields_by_name['target_group_spec'].message_type = _TARGETGROUPSPEC
_LOADBALANCERSPEC.fields_by_name['max_opening_traffic_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TARGETGROUPSPEC_LABELSENTRY.containing_type = _TARGETGROUPSPEC
_TARGETGROUPSPEC.fields_by_name['labels'].message_type = _TARGETGROUPSPEC_LABELSENTRY
_APPLICATIONLOADBALANCERSPEC.fields_by_name['target_group_spec'].message_type = _APPLICATIONTARGETGROUPSPEC
_APPLICATIONLOADBALANCERSPEC.fields_by_name['max_opening_traffic_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_APPLICATIONTARGETGROUPSPEC_LABELSENTRY.containing_type = _APPLICATIONTARGETGROUPSPEC
_APPLICATIONTARGETGROUPSPEC.fields_by_name['labels'].message_type = _APPLICATIONTARGETGROUPSPEC_LABELSENTRY
_HEALTHCHECKSSPEC.fields_by_name['health_check_specs'].message_type = _HEALTHCHECKSPEC
_HEALTHCHECKSSPEC.fields_by_name['max_checking_health_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECKSPEC_TCPOPTIONS.containing_type = _HEALTHCHECKSPEC
_HEALTHCHECKSPEC_HTTPOPTIONS.containing_type = _HEALTHCHECKSPEC
_HEALTHCHECKSPEC.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECKSPEC.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECKSPEC.fields_by_name['tcp_options'].message_type = _HEALTHCHECKSPEC_TCPOPTIONS
_HEALTHCHECKSPEC.fields_by_name['http_options'].message_type = _HEALTHCHECKSPEC_HTTPOPTIONS
_HEALTHCHECKSPEC.oneofs_by_name['health_check_options'].fields.append(
  _HEALTHCHECKSPEC.fields_by_name['tcp_options'])
_HEALTHCHECKSPEC.fields_by_name['tcp_options'].containing_oneof = _HEALTHCHECKSPEC.oneofs_by_name['health_check_options']
_HEALTHCHECKSPEC.oneofs_by_name['health_check_options'].fields.append(
  _HEALTHCHECKSPEC.fields_by_name['http_options'])
_HEALTHCHECKSPEC.fields_by_name['http_options'].containing_oneof = _HEALTHCHECKSPEC.oneofs_by_name['health_check_options']
_MANAGEDINSTANCE.fields_by_name['status'].enum_type = _MANAGEDINSTANCE_STATUS
_MANAGEDINSTANCE.fields_by_name['network_interfaces'].message_type = _NETWORKINTERFACE
_MANAGEDINSTANCE.fields_by_name['status_changed_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MANAGEDINSTANCE_STATUS.containing_type = _MANAGEDINSTANCE
_NETWORKINTERFACE.fields_by_name['primary_v4_address'].message_type = _PRIMARYADDRESS
_NETWORKINTERFACE.fields_by_name['primary_v6_address'].message_type = _PRIMARYADDRESS
_PRIMARYADDRESS.fields_by_name['one_to_one_nat'].message_type = _ONETOONENAT
_PRIMARYADDRESS.fields_by_name['dns_records'].message_type = _DNSRECORD
_ONETOONENAT.fields_by_name['ip_version'].enum_type = _IPVERSION
_ONETOONENAT.fields_by_name['dns_records'].message_type = _DNSRECORD
_LOGRECORD.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['InstanceGroup'] = _INSTANCEGROUP
DESCRIPTOR.message_types_by_name['ApplicationLoadBalancerState'] = _APPLICATIONLOADBALANCERSTATE
DESCRIPTOR.message_types_by_name['Variable'] = _VARIABLE
DESCRIPTOR.message_types_by_name['LoadBalancerState'] = _LOADBALANCERSTATE
DESCRIPTOR.message_types_by_name['ManagedInstancesState'] = _MANAGEDINSTANCESSTATE
DESCRIPTOR.message_types_by_name['ScalePolicy'] = _SCALEPOLICY
DESCRIPTOR.message_types_by_name['DeployPolicy'] = _DEPLOYPOLICY
DESCRIPTOR.message_types_by_name['AllocationPolicy'] = _ALLOCATIONPOLICY
DESCRIPTOR.message_types_by_name['InstanceTemplate'] = _INSTANCETEMPLATE
DESCRIPTOR.message_types_by_name['AttachedFilesystemSpec'] = _ATTACHEDFILESYSTEMSPEC
DESCRIPTOR.message_types_by_name['PlacementPolicy'] = _PLACEMENTPOLICY
DESCRIPTOR.message_types_by_name['ResourcesSpec'] = _RESOURCESSPEC
DESCRIPTOR.message_types_by_name['AttachedDiskSpec'] = _ATTACHEDDISKSPEC
DESCRIPTOR.message_types_by_name['NetworkInterfaceSpec'] = _NETWORKINTERFACESPEC
DESCRIPTOR.message_types_by_name['PrimaryAddressSpec'] = _PRIMARYADDRESSSPEC
DESCRIPTOR.message_types_by_name['OneToOneNatSpec'] = _ONETOONENATSPEC
DESCRIPTOR.message_types_by_name['DnsRecordSpec'] = _DNSRECORDSPEC
DESCRIPTOR.message_types_by_name['SchedulingPolicy'] = _SCHEDULINGPOLICY
DESCRIPTOR.message_types_by_name['NetworkSettings'] = _NETWORKSETTINGS
DESCRIPTOR.message_types_by_name['LoadBalancerSpec'] = _LOADBALANCERSPEC
DESCRIPTOR.message_types_by_name['TargetGroupSpec'] = _TARGETGROUPSPEC
DESCRIPTOR.message_types_by_name['ApplicationLoadBalancerSpec'] = _APPLICATIONLOADBALANCERSPEC
DESCRIPTOR.message_types_by_name['ApplicationTargetGroupSpec'] = _APPLICATIONTARGETGROUPSPEC
DESCRIPTOR.message_types_by_name['HealthChecksSpec'] = _HEALTHCHECKSSPEC
DESCRIPTOR.message_types_by_name['HealthCheckSpec'] = _HEALTHCHECKSPEC
DESCRIPTOR.message_types_by_name['ManagedInstance'] = _MANAGEDINSTANCE
DESCRIPTOR.message_types_by_name['NetworkInterface'] = _NETWORKINTERFACE
DESCRIPTOR.message_types_by_name['PrimaryAddress'] = _PRIMARYADDRESS
DESCRIPTOR.message_types_by_name['OneToOneNat'] = _ONETOONENAT
DESCRIPTOR.message_types_by_name['DnsRecord'] = _DNSRECORD
DESCRIPTOR.message_types_by_name['LogRecord'] = _LOGRECORD
DESCRIPTOR.enum_types_by_name['IpVersion'] = _IPVERSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InstanceGroup = _reflection.GeneratedProtocolMessageType('InstanceGroup', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _INSTANCEGROUP_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.InstanceGroup.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _INSTANCEGROUP,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.InstanceGroup)
  })
_sym_db.RegisterMessage(InstanceGroup)
_sym_db.RegisterMessage(InstanceGroup.LabelsEntry)

ApplicationLoadBalancerState = _reflection.GeneratedProtocolMessageType('ApplicationLoadBalancerState', (_message.Message,), {
  'DESCRIPTOR' : _APPLICATIONLOADBALANCERSTATE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerState)
  })
_sym_db.RegisterMessage(ApplicationLoadBalancerState)

Variable = _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.Variable)
  })
_sym_db.RegisterMessage(Variable)

LoadBalancerState = _reflection.GeneratedProtocolMessageType('LoadBalancerState', (_message.Message,), {
  'DESCRIPTOR' : _LOADBALANCERSTATE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.LoadBalancerState)
  })
_sym_db.RegisterMessage(LoadBalancerState)

ManagedInstancesState = _reflection.GeneratedProtocolMessageType('ManagedInstancesState', (_message.Message,), {

  'Statuses' : _reflection.GeneratedProtocolMessageType('Statuses', (_message.Message,), {
    'DESCRIPTOR' : _MANAGEDINSTANCESSTATE_STATUSES,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ManagedInstancesState.Statuses)
    })
  ,
  'DESCRIPTOR' : _MANAGEDINSTANCESSTATE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ManagedInstancesState)
  })
_sym_db.RegisterMessage(ManagedInstancesState)
_sym_db.RegisterMessage(ManagedInstancesState.Statuses)

ScalePolicy = _reflection.GeneratedProtocolMessageType('ScalePolicy', (_message.Message,), {

  'AutoScale' : _reflection.GeneratedProtocolMessageType('AutoScale', (_message.Message,), {
    'DESCRIPTOR' : _SCALEPOLICY_AUTOSCALE,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ScalePolicy.AutoScale)
    })
  ,

  'CpuUtilizationRule' : _reflection.GeneratedProtocolMessageType('CpuUtilizationRule', (_message.Message,), {
    'DESCRIPTOR' : _SCALEPOLICY_CPUUTILIZATIONRULE,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ScalePolicy.CpuUtilizationRule)
    })
  ,

  'CustomRule' : _reflection.GeneratedProtocolMessageType('CustomRule', (_message.Message,), {

    'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
      'DESCRIPTOR' : _SCALEPOLICY_CUSTOMRULE_LABELSENTRY,
      '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule.LabelsEntry)
      })
    ,
    'DESCRIPTOR' : _SCALEPOLICY_CUSTOMRULE,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ScalePolicy.CustomRule)
    })
  ,

  'FixedScale' : _reflection.GeneratedProtocolMessageType('FixedScale', (_message.Message,), {
    'DESCRIPTOR' : _SCALEPOLICY_FIXEDSCALE,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ScalePolicy.FixedScale)
    })
  ,
  'DESCRIPTOR' : _SCALEPOLICY,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ScalePolicy)
  })
_sym_db.RegisterMessage(ScalePolicy)
_sym_db.RegisterMessage(ScalePolicy.AutoScale)
_sym_db.RegisterMessage(ScalePolicy.CpuUtilizationRule)
_sym_db.RegisterMessage(ScalePolicy.CustomRule)
_sym_db.RegisterMessage(ScalePolicy.CustomRule.LabelsEntry)
_sym_db.RegisterMessage(ScalePolicy.FixedScale)

DeployPolicy = _reflection.GeneratedProtocolMessageType('DeployPolicy', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYPOLICY,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.DeployPolicy)
  })
_sym_db.RegisterMessage(DeployPolicy)

AllocationPolicy = _reflection.GeneratedProtocolMessageType('AllocationPolicy', (_message.Message,), {

  'Zone' : _reflection.GeneratedProtocolMessageType('Zone', (_message.Message,), {
    'DESCRIPTOR' : _ALLOCATIONPOLICY_ZONE,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.AllocationPolicy.Zone)
    })
  ,
  'DESCRIPTOR' : _ALLOCATIONPOLICY,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.AllocationPolicy)
  })
_sym_db.RegisterMessage(AllocationPolicy)
_sym_db.RegisterMessage(AllocationPolicy.Zone)

InstanceTemplate = _reflection.GeneratedProtocolMessageType('InstanceTemplate', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _INSTANCETEMPLATE_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.InstanceTemplate.LabelsEntry)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INSTANCETEMPLATE_METADATAENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.InstanceTemplate.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INSTANCETEMPLATE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.InstanceTemplate)
  })
_sym_db.RegisterMessage(InstanceTemplate)
_sym_db.RegisterMessage(InstanceTemplate.LabelsEntry)
_sym_db.RegisterMessage(InstanceTemplate.MetadataEntry)

AttachedFilesystemSpec = _reflection.GeneratedProtocolMessageType('AttachedFilesystemSpec', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHEDFILESYSTEMSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.AttachedFilesystemSpec)
  })
_sym_db.RegisterMessage(AttachedFilesystemSpec)

PlacementPolicy = _reflection.GeneratedProtocolMessageType('PlacementPolicy', (_message.Message,), {

  'HostAffinityRule' : _reflection.GeneratedProtocolMessageType('HostAffinityRule', (_message.Message,), {
    'DESCRIPTOR' : _PLACEMENTPOLICY_HOSTAFFINITYRULE,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.PlacementPolicy.HostAffinityRule)
    })
  ,
  'DESCRIPTOR' : _PLACEMENTPOLICY,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.PlacementPolicy)
  })
_sym_db.RegisterMessage(PlacementPolicy)
_sym_db.RegisterMessage(PlacementPolicy.HostAffinityRule)

ResourcesSpec = _reflection.GeneratedProtocolMessageType('ResourcesSpec', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ResourcesSpec)
  })
_sym_db.RegisterMessage(ResourcesSpec)

AttachedDiskSpec = _reflection.GeneratedProtocolMessageType('AttachedDiskSpec', (_message.Message,), {

  'DiskSpec' : _reflection.GeneratedProtocolMessageType('DiskSpec', (_message.Message,), {
    'DESCRIPTOR' : _ATTACHEDDISKSPEC_DISKSPEC,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec.DiskSpec)
    })
  ,
  'DESCRIPTOR' : _ATTACHEDDISKSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.AttachedDiskSpec)
  })
_sym_db.RegisterMessage(AttachedDiskSpec)
_sym_db.RegisterMessage(AttachedDiskSpec.DiskSpec)

NetworkInterfaceSpec = _reflection.GeneratedProtocolMessageType('NetworkInterfaceSpec', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKINTERFACESPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.NetworkInterfaceSpec)
  })
_sym_db.RegisterMessage(NetworkInterfaceSpec)

PrimaryAddressSpec = _reflection.GeneratedProtocolMessageType('PrimaryAddressSpec', (_message.Message,), {
  'DESCRIPTOR' : _PRIMARYADDRESSSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.PrimaryAddressSpec)
  })
_sym_db.RegisterMessage(PrimaryAddressSpec)

OneToOneNatSpec = _reflection.GeneratedProtocolMessageType('OneToOneNatSpec', (_message.Message,), {
  'DESCRIPTOR' : _ONETOONENATSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.OneToOneNatSpec)
  })
_sym_db.RegisterMessage(OneToOneNatSpec)

DnsRecordSpec = _reflection.GeneratedProtocolMessageType('DnsRecordSpec', (_message.Message,), {
  'DESCRIPTOR' : _DNSRECORDSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.DnsRecordSpec)
  })
_sym_db.RegisterMessage(DnsRecordSpec)

SchedulingPolicy = _reflection.GeneratedProtocolMessageType('SchedulingPolicy', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULINGPOLICY,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.SchedulingPolicy)
  })
_sym_db.RegisterMessage(SchedulingPolicy)

NetworkSettings = _reflection.GeneratedProtocolMessageType('NetworkSettings', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKSETTINGS,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.NetworkSettings)
  })
_sym_db.RegisterMessage(NetworkSettings)

LoadBalancerSpec = _reflection.GeneratedProtocolMessageType('LoadBalancerSpec', (_message.Message,), {
  'DESCRIPTOR' : _LOADBALANCERSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.LoadBalancerSpec)
  })
_sym_db.RegisterMessage(LoadBalancerSpec)

TargetGroupSpec = _reflection.GeneratedProtocolMessageType('TargetGroupSpec', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TARGETGROUPSPEC_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.TargetGroupSpec.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _TARGETGROUPSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.TargetGroupSpec)
  })
_sym_db.RegisterMessage(TargetGroupSpec)
_sym_db.RegisterMessage(TargetGroupSpec.LabelsEntry)

ApplicationLoadBalancerSpec = _reflection.GeneratedProtocolMessageType('ApplicationLoadBalancerSpec', (_message.Message,), {
  'DESCRIPTOR' : _APPLICATIONLOADBALANCERSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerSpec)
  })
_sym_db.RegisterMessage(ApplicationLoadBalancerSpec)

ApplicationTargetGroupSpec = _reflection.GeneratedProtocolMessageType('ApplicationTargetGroupSpec', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _APPLICATIONTARGETGROUPSPEC_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _APPLICATIONTARGETGROUPSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ApplicationTargetGroupSpec)
  })
_sym_db.RegisterMessage(ApplicationTargetGroupSpec)
_sym_db.RegisterMessage(ApplicationTargetGroupSpec.LabelsEntry)

HealthChecksSpec = _reflection.GeneratedProtocolMessageType('HealthChecksSpec', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKSSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.HealthChecksSpec)
  })
_sym_db.RegisterMessage(HealthChecksSpec)

HealthCheckSpec = _reflection.GeneratedProtocolMessageType('HealthCheckSpec', (_message.Message,), {

  'TcpOptions' : _reflection.GeneratedProtocolMessageType('TcpOptions', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECKSPEC_TCPOPTIONS,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.TcpOptions)
    })
  ,

  'HttpOptions' : _reflection.GeneratedProtocolMessageType('HttpOptions', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECKSPEC_HTTPOPTIONS,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.HealthCheckSpec.HttpOptions)
    })
  ,
  'DESCRIPTOR' : _HEALTHCHECKSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.HealthCheckSpec)
  })
_sym_db.RegisterMessage(HealthCheckSpec)
_sym_db.RegisterMessage(HealthCheckSpec.TcpOptions)
_sym_db.RegisterMessage(HealthCheckSpec.HttpOptions)

ManagedInstance = _reflection.GeneratedProtocolMessageType('ManagedInstance', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDINSTANCE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ManagedInstance)
  })
_sym_db.RegisterMessage(ManagedInstance)

NetworkInterface = _reflection.GeneratedProtocolMessageType('NetworkInterface', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKINTERFACE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.NetworkInterface)
  })
_sym_db.RegisterMessage(NetworkInterface)

PrimaryAddress = _reflection.GeneratedProtocolMessageType('PrimaryAddress', (_message.Message,), {
  'DESCRIPTOR' : _PRIMARYADDRESS,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.PrimaryAddress)
  })
_sym_db.RegisterMessage(PrimaryAddress)

OneToOneNat = _reflection.GeneratedProtocolMessageType('OneToOneNat', (_message.Message,), {
  'DESCRIPTOR' : _ONETOONENAT,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.OneToOneNat)
  })
_sym_db.RegisterMessage(OneToOneNat)

DnsRecord = _reflection.GeneratedProtocolMessageType('DnsRecord', (_message.Message,), {
  'DESCRIPTOR' : _DNSRECORD,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.DnsRecord)
  })
_sym_db.RegisterMessage(DnsRecord)

LogRecord = _reflection.GeneratedProtocolMessageType('LogRecord', (_message.Message,), {
  'DESCRIPTOR' : _LOGRECORD,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.LogRecord)
  })
_sym_db.RegisterMessage(LogRecord)


DESCRIPTOR._options = None
_INSTANCEGROUP_LABELSENTRY._options = None
_VARIABLE.fields_by_name['key']._options = None
_VARIABLE.fields_by_name['value']._options = None
_SCALEPOLICY_AUTOSCALE.fields_by_name['min_zone_size']._options = None
_SCALEPOLICY_AUTOSCALE.fields_by_name['max_size']._options = None
_SCALEPOLICY_AUTOSCALE.fields_by_name['measurement_duration']._options = None
_SCALEPOLICY_AUTOSCALE.fields_by_name['warmup_duration']._options = None
_SCALEPOLICY_AUTOSCALE.fields_by_name['stabilization_duration']._options = None
_SCALEPOLICY_AUTOSCALE.fields_by_name['initial_size']._options = None
_SCALEPOLICY_AUTOSCALE.fields_by_name['custom_rules']._options = None
_SCALEPOLICY_CPUUTILIZATIONRULE.fields_by_name['utilization_target']._options = None
_SCALEPOLICY_CUSTOMRULE_LABELSENTRY._options = None
_SCALEPOLICY_CUSTOMRULE.fields_by_name['rule_type']._options = None
_SCALEPOLICY_CUSTOMRULE.fields_by_name['metric_type']._options = None
_SCALEPOLICY_CUSTOMRULE.fields_by_name['metric_name']._options = None
_SCALEPOLICY_CUSTOMRULE.fields_by_name['labels']._options = None
_SCALEPOLICY_CUSTOMRULE.fields_by_name['target']._options = None
_SCALEPOLICY_CUSTOMRULE.fields_by_name['folder_id']._options = None
_SCALEPOLICY_CUSTOMRULE.fields_by_name['service']._options = None
_SCALEPOLICY_FIXEDSCALE.fields_by_name['size']._options = None
_SCALEPOLICY.oneofs_by_name['scale_type']._options = None
_DEPLOYPOLICY.fields_by_name['max_unavailable']._options = None
_DEPLOYPOLICY.fields_by_name['max_deleting']._options = None
_DEPLOYPOLICY.fields_by_name['max_creating']._options = None
_DEPLOYPOLICY.fields_by_name['max_expansion']._options = None
_DEPLOYPOLICY.fields_by_name['startup_duration']._options = None
_ALLOCATIONPOLICY_ZONE.fields_by_name['zone_id']._options = None
_ALLOCATIONPOLICY.fields_by_name['zones']._options = None
_INSTANCETEMPLATE_LABELSENTRY._options = None
_INSTANCETEMPLATE_METADATAENTRY._options = None
_INSTANCETEMPLATE.fields_by_name['description']._options = None
_INSTANCETEMPLATE.fields_by_name['labels']._options = None
_INSTANCETEMPLATE.fields_by_name['platform_id']._options = None
_INSTANCETEMPLATE.fields_by_name['resources_spec']._options = None
_INSTANCETEMPLATE.fields_by_name['metadata']._options = None
_INSTANCETEMPLATE.fields_by_name['boot_disk_spec']._options = None
_INSTANCETEMPLATE.fields_by_name['secondary_disk_specs']._options = None
_INSTANCETEMPLATE.fields_by_name['network_interface_specs']._options = None
_INSTANCETEMPLATE.fields_by_name['name']._options = None
_INSTANCETEMPLATE.fields_by_name['hostname']._options = None
_ATTACHEDFILESYSTEMSPEC.fields_by_name['device_name']._options = None
_ATTACHEDFILESYSTEMSPEC.fields_by_name['filesystem_id']._options = None
_RESOURCESSPEC.fields_by_name['memory']._options = None
_RESOURCESSPEC.fields_by_name['cores']._options = None
_RESOURCESSPEC.fields_by_name['core_fraction']._options = None
_RESOURCESSPEC.fields_by_name['gpus']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['description']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['type_id']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['size']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id']._options = None
_ATTACHEDDISKSPEC.fields_by_name['mode']._options = None
_ATTACHEDDISKSPEC.fields_by_name['device_name']._options = None
_ATTACHEDDISKSPEC.fields_by_name['disk_spec']._options = None
_ATTACHEDDISKSPEC.fields_by_name['disk_id']._options = None
_ATTACHEDDISKSPEC.fields_by_name['name']._options = None
_DNSRECORDSPEC.fields_by_name['fqdn']._options = None
_DNSRECORDSPEC.fields_by_name['ttl']._options = None
_LOADBALANCERSPEC.fields_by_name['max_opening_traffic_duration']._options = None
_TARGETGROUPSPEC_LABELSENTRY._options = None
_TARGETGROUPSPEC.fields_by_name['name']._options = None
_TARGETGROUPSPEC.fields_by_name['description']._options = None
_TARGETGROUPSPEC.fields_by_name['labels']._options = None
_APPLICATIONLOADBALANCERSPEC.fields_by_name['target_group_spec']._options = None
_APPLICATIONLOADBALANCERSPEC.fields_by_name['max_opening_traffic_duration']._options = None
_APPLICATIONTARGETGROUPSPEC_LABELSENTRY._options = None
_HEALTHCHECKSSPEC.fields_by_name['health_check_specs']._options = None
_HEALTHCHECKSSPEC.fields_by_name['max_checking_health_duration']._options = None
_HEALTHCHECKSPEC_TCPOPTIONS.fields_by_name['port']._options = None
_HEALTHCHECKSPEC_HTTPOPTIONS.fields_by_name['port']._options = None
_HEALTHCHECKSPEC.oneofs_by_name['health_check_options']._options = None
_HEALTHCHECKSPEC.fields_by_name['interval']._options = None
_HEALTHCHECKSPEC.fields_by_name['timeout']._options = None
_HEALTHCHECKSPEC.fields_by_name['unhealthy_threshold']._options = None
_HEALTHCHECKSPEC.fields_by_name['healthy_threshold']._options = None
_DNSRECORD.fields_by_name['fqdn']._options = None
_DNSRECORD.fields_by_name['ttl']._options = None
# @@protoc_insertion_point(module_scope)
